@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.18';
+$Test::BDD::Cucumber::Executor::VERSION = '0.19';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 DESCRIPTION
 
@@ -176,11 +176,11 @@ sub execute_scenario {
             feature  => $feature_stash,
             step     => {},
         },
-    
+
         # Step-specific info
         feature  => $feature,
         scenario => $outline,
-    
+
         # Communicators
         harness  => $harness,
 
@@ -204,10 +204,10 @@ sub execute_scenario {
                     %context_defaults,
                     verb => 'before',
                 });
-    
+
                 my $result = $self->dispatch( $context, $before_step,
                         $outline_stash->{'short_circuit'} );
-    
+
                 # If it didn't pass, short-circuit the rest
                 unless ( $result->result eq 'passing' ) {
                     $outline_stash->{'short_circuit'}++;
@@ -267,7 +267,7 @@ sub execute_scenario {
                     %context_defaults,
                     verb => 'after',
                 });
-    
+
                 # All After steps should happen, to ensure cleanup
                 my $result = $self->dispatch( $context, $after_step, 0 );
             }
@@ -374,7 +374,16 @@ sub dispatch {
         $context->matches([ $context->text =~ $regular_expression ]);
 
         # Execute!
-        eval { $coderef->( $context ) };
+        eval {
+            no warnings 'redefine';
+            local *Test::BDD::Cucumber::StepFile::S = sub {
+                return $context->stash->{'scenario'}
+            };
+            local *Test::BDD::Cucumber::StepFile::C = sub {
+                return $context
+            };
+            $coderef->( $context )
+        };
         if ( $@ ) {
             $Test::Builder::Test->ok( 0, "Test compiled" );
             $Test::Builder::Test->diag( $@ );
